@@ -4,6 +4,7 @@ lung2 <- subset(lung, select = c(time, status, age, sex))
 lung2$status <- lung2$status - 1
 lung2$sex <- lung2$sex - 1
 
+library(qris)
 fm <- Surv(time, status) ~ age + sex
 fit <- qris(fm, data = lung2, t0 = 30, Q = 0.5, nB = 50, "nonsmooth", "fmb")
 
@@ -14,7 +15,7 @@ plot(fit)
 plot(fit, nB = 0)
 
 ## Plot feature can update qris calls 
-fit <- plot(fit, Qs = 3:6 / 10, t0s = 1:6 * 10, exportDat = TRUE)
+fit <- plot(fit, Qs = 3:6 / 10, t0s = 1:6 * 10)
 
 ## Faster after updating the qris call
 plot(fit, byQs = FALSE)
@@ -23,3 +24,6 @@ plot(fit, byQs = TRUE)
 plot(fit, byQs = FALSE, vari = c("sex", "age"))
 plot(fit, byQs = TRUE, vari = c("sex", "age"))
 
+## Extra ggplot components
+library(ggplot2)
+plot(fit, byQs = FALSE, vari = c("sex", "age"), ggextra = theme(legend.position = "none"))
